@@ -1,5 +1,19 @@
 context("PipeOpScale")
 
+test_that("PipeOpScale - basic properties", {
+  op = PipeOpScale$new()
+  task = mlr_tasks$get("iris")
+  expect_pipeop(op)
+
+  expect_datapreproc_pipeop_class(PipeOpScale, task = task)
+
+  result = train_pipeop(op, inputs = list(task))
+  expect_task(result[[1]])
+
+  result = predict_pipeop(op, inputs = list(task))
+  expect_task(result[[1]])
+})
+
 test_that("basic properties", {
   expect_datapreproc_pipeop_class(PipeOpScale, task = mlr_tasks$get("iris"))
 
